require_relative '../test_helper'
require_relative '../../lib/dot_env/parser'
require_relative '../../lib/dot_env/environment'

describe DotEnv::Environment do
  let(:env) { DotEnv::Environment.new(DotEnv::Parser, ARGV) }

  before do
    ENV['THE_MEANING_OF_LIFE'] = '42'
  end

  describe "fetch" do
    it "reads environment variables" do
      env.fetch('THE_MEANING_OF_LIFE').must_equal '42'
    end

    it "reads environment variables with defaults" do
      env.fetch('THE_MEANING_OF_LIFE', 'hello').must_equal '42'
    end

    it "uses default if there is no such variable" do
      env.fetch('NONEXISTINGVARIABLE', 'hello').must_equal 'hello'
    end
  end

  describe "check_test_runner" do
    it "returns 'testing' when rspec runs" do
      env.cmdline_args = ['spec']

      env.check_test_runner.must_equal 'testing'
    end

    it "returns 'testing' when cucumber runs" do
      env.cmdline_args = ['cucumber']

      env.check_test_runner.must_equal 'testing'
    end

    it "returns nil when no test runs" do
      env.cmdline_args = []

      env.check_test_runner.must_equal nil
    end
  end

  describe "check_test_file" do
    it "returns 'testing' when a spec file runs" do
      argword = 'path/to/something_spec.rb'

      env.check_test_file(argword).must_equal 'testing'
    end

    it "returns 'testing' when cucumber runs" do
      argword = 'path/to/something.feature'

      env.check_test_file(argword).must_equal 'testing'
    end

    it "returns nil when no test runs" do
      argword = ''

      env.check_test_file(argword).must_equal nil
    end
  end

  describe "check_if_testing" do
    it "returns 'testing' when there is a testfile in the arguments" do
      env.cmdline_args = ['ruby', 'path/to/test_file.rb']

      env.check_if_testing.must_equal 'testing'
    end

    it "returns nil when no test runs" do
      env.cmdline_args = []

      env.check_if_testing.must_equal nil
    end
  end

  it "sets the current environment" do
    ENV['APP_ENV'] = 'nothing'
    env.set_current('strange')

    ENV['APP_ENV'].must_equal 'strange'
  end

  describe "get_current_env" do
    it "returns 'testing' when there is a testfile in the arguments" do
      env.cmdline_args = ['ruby', 'path/to/test_file.rb']

      env.get_current.must_equal 'testing'
    end

    it "returns 'testing' when a test runner runs" do
      env.cmdline_args = ['cucumber']

      env.get_current.must_equal 'testing'
    end

    it "returns 'dev' when there are no tests, but the APP_ENV is 'dev'" do
      ENV['APP_ENV'] = 'dev'
      env.cmdline_args = []

      env.get_current.must_equal 'dev'
    end

    it "returns 'development' otherwise" do
      ENV['APP_ENV'] = nil
      env.cmdline_args = []

      env.get_current.must_equal 'development'
    end
  end
end
